@@ -14,6 +14,7 @@
 # pofile = pofile()
 # mainSearchByContent = MainSearchByContent()
 import pofile
+import search4file
 
 # todo：输入文件路径
 # @except_dec()
@@ -29,7 +30,7 @@ def replace4filename(path, del_content, replace_content=None):
 # @except_dec()
 @instruction
 def search_by_content(search_path, content):  # 定义 search() 函数，传入 "path" 文件路径， "target" 要查找的目标文件
-    pofile.search_by_content(search_path, content)
+    search4file.search_by_content(search_path=search_path, search_content=content)
 
 
 # author：https://github.com/CoderWanFeng/python-office/pull/72
@@ -74,3 +75,8 @@ def add_line_by_type(add_line_dict: dict, file_path, file_type='.py', output_pat
 @instruction
 def group_by_name(path, output_path=None, del_old_file=None):
     pofile.group_by_name(path, output_path, del_old_file)
+
+
+@instruction
+def get_files(path: str, name: str = '', suffix: str = None, sub: bool = False, level: int = 0) -> list:
+    return pofile.get_files(path, name, suffix, sub, level)
